@@ -33,7 +33,16 @@ def handle_input_data(request):
     """
     因为udp和tcp的处理实在一样，所以还是抽离出来吧
     """
-    request.server.logger.debug('jdata: %s', request._json_data)
+    request.server.logger.debug('raw_data: %s', request._raw_data)
+
+    try:
+        request._json_data = json.loads(request._raw_data)
+    except Exception, e:
+        error = 'parse raw_data fail. e: %s, raw_data: %s' % (e, request._raw_data)
+        request.server.logger.error(error)
+        request.push(request.server.make_rsp(ret=constants.RET_SYSTEM, error=error))
+        request.close()
+        return
 
     if not isinstance(request.json_data, dict):
         error = 'json_data is not dict. json_data: %s' % request.json_data
@@ -227,11 +236,11 @@ class TcpRequestHandler(asynchat.async_chat):
         self.set_terminator(terminator)
 
         # create_request_func_list
-        for func in self._server.create_request_func_list:
+        for func in self.server.create_request_func_list:
             try:
                 func(self)
             except Exception, e:
-                self._server.logger.error('create_request_func_list raise exception. func: %s, e: %s',
+                self.server.logger.error('create_request_func_list raise exception. func: %s, e: %s',
                                           func.__name__, e)
 
     def collect_incoming_data(self, data):
@@ -242,22 +251,20 @@ class TcpRequestHandler(asynchat.async_chat):
     def found_terminator(self):
         # 这里会把incoming data 清空
         self._raw_data = self._get_data()
-        self._json_data = json.loads(self._raw_data)
-
         handle_input_data(self)
 
     def close(self):
         # handle_close 只能处理对方关闭链接的情况，handle_close中也是调用了close
         # 对端关闭链接，或者自己关闭链接时，调用
         asynchat.async_chat.close(self)
-        self._server.logger.debug('socket closed')
+        self.server.logger.debug('socket closed')
 
         # teardown_request_func_list
-        for func in self._server.teardown_request_func_list:
+        for func in self.server.teardown_request_func_list:
             try:
                 func(self)
             except Exception, e:
-                self._server.logger.error('teardown_request_func_list raise exception. func: %s, e: %s',
+                self.server.logger.error('teardown_request_func_list raise exception. func: %s, e: %s',
                                           func.__name__, e)
 
     @property
@@ -299,8 +306,6 @@ class UdpServer(asyncore.dispatcher, CallBackMgr):
     @catch_exc
     def handle_read(self):
         self._raw_data, self._address = self.socket.recvfrom(constants.PACKAGE_SIZE)
-        self._json_data = json.loads(self._raw_data)
-
         handle_input_data(self)
 
     def run(self, host, port):
